@@ -45,11 +45,17 @@ namespace xsimd
             unsigned avx : 1;
             unsigned fma3_avx : 1;
             unsigned avx2 : 1;
+            unsigned avxvnni : 1;
             unsigned fma3_avx2 : 1;
             unsigned avx512f : 1;
             unsigned avx512cd : 1;
             unsigned avx512dq : 1;
             unsigned avx512bw : 1;
+            unsigned avx512er : 1;
+            unsigned avx512pf : 1;
+            unsigned avx512ifma : 1;
+            unsigned avx512vbmi : 1;
+            unsigned avx512vnni : 1;
             unsigned neon : 1;
             unsigned neon64 : 1;
             unsigned sve : 1;
@@ -99,14 +105,14 @@ namespace xsimd
 
                 best = ::xsimd::rvv::version() * rvv;
 #elif defined(__x86_64__) || defined(__i386__) || defined(_M_AMD64) || defined(_M_IX86)
-                auto get_cpuid = [](int reg[4], int func_id) noexcept
+                auto get_cpuid = [](int reg[4], int level, int count = 0) noexcept
                 {
 
 #if defined(_MSC_VER)
-                    __cpuidex(reg, func_id, 0);
+                    __cpuidex(reg, level, count);
 
 #elif defined(__INTEL_COMPILER)
-                    __cpuid(reg, func_id);
+                    __cpuid(reg, level);
 
 #elif defined(__GNUC__) || defined(__clang__)
 
@@ -117,13 +123,13 @@ namespace xsimd
                             "xchg{l}\t{%%}ebx, %1\n\t"
                             : "=a"(reg[0]), "=r"(reg[1]), "=c"(reg[2]),
                               "=d"(reg[3])
-                            : "a"(func_id), "c"(0));
+                            : "0"(level), "2"(count));
 
 #else
                     __asm__("cpuid\n\t"
                             : "=a"(reg[0]), "=b"(reg[1]), "=c"(reg[2]),
                               "=d"(reg[3])
-                            : "a"(func_id), "c"(0));
+                            : "0"(level), "2"(count));
 #endif
 
 #else
@@ -176,6 +182,11 @@ namespace xsimd
                 avx2 = regs7[1] >> 5 & 1;
                 best = std::max(best, avx2::version() * avx2);
 
+                int regs7a[4];
+                get_cpuid(regs7a, 0x7, 0x1);
+                avxvnni = regs7a[0] >> 4 & 1;
+                best = std::max(best, avxvnni::version() * avxvnni * avx2);
+
                 fma3_avx2 = avx2 && fma3_sse;
                 best = std::max(best, fma3<xsimd::avx2>::version() * fma3_avx2);
 
@@ -191,6 +202,20 @@ namespace xsimd
                 avx512bw = regs7[1] >> 30 & 1;
                 best = std::max(best, avx512bw::version() * avx512bw * avx512dq * avx512cd * avx512f);
 
+                avx512er = regs7[1] >> 27 & 1;
+                best = std::max(best, avx512er::version() * avx512er * avx512cd * avx512f);
+
+                avx512pf = regs7[1] >> 26 & 1;
+                best = std::max(best, avx512pf::version() * avx512pf * avx512er * avx512cd * avx512f);
+
+                avx512ifma = regs7[1] >> 21 & 1;
+                best = std::max(best, avx512ifma::version() * avx512ifma * avx512bw * avx512dq * avx512cd * avx512f);
+
+                avx512vbmi = regs7[2] >> 1 & 1;
+                best = std::max(best, avx512vbmi::version() * avx512vbmi * avx512ifma * avx512bw * avx512dq * avx512cd * avx512f);
+
+                avx512vnni = regs7[2] >> 11 & 1;
+                best = std::max(best, avx512vnni::version() * avx512vnni * avx512vbmi * avx512ifma * avx512bw * avx512dq * avx512cd * avx512f);
 #endif
             }
         };
